package cz.moneta.test.dsl.mwf;

import cz.moneta.test.harness.support.mwf.Parameter;
import cz.moneta.test.harness.support.mwf.MwfRequest;

public interface MWFBV5 extends MwfRequest<MWFBV5, MWFBV5Response> {

    @Parameter(name = "AAAdresat")
    MWFBV5 aAAdresat(String aAAdresat);
    @Parameter(name = "AACO")
    MWFBV5 aaco(String aaco);
    @Parameter(name = "AACP")
    MWFBV5 aacp(String aacp);
    @Parameter(name = "AACtvrt")
    MWFBV5 aACtvrt(String aACtvrt);
    @Parameter(name = "AAObec")
    MWFBV5 aAObec(String aAObec);
    @Parameter(name = "AAPSC")
    MWFBV5 aapsc(String aapsc);
    @Parameter(name = "AAPosta")
    MWFBV5 aAPosta(String aAPosta);
    @Parameter(name = "AAUlice")
    MWFBV5 aAUlice(String aAUlice);
    @Parameter(name = "AAZeme")
    MWFBV5 aAZeme(String aAZeme);
    @Parameter(name = "AVPole")
    MWFBV5 aVPole(String aVPole);
    @Parameter(name = "CIF")
    MWFBV5 cif(String cif);
    @Parameter(name = "Cache")
    MWFBV5 cache(Long cache);
    @Parameter(name = "CastkaDalsiPlatby")
    MWFBV5 castkaDalsiPlatby(Double castkaDalsiPlatby);
    @Parameter(name = "CastkaKonecnePlatby")
    MWFBV5 castkaKonecnePlatby(Double castkaKonecnePlatby);
    @Parameter(name = "CastkaPrvniPlatby")
    MWFBV5 castkaPrvniPlatby(Double castkaPrvniPlatby);
    @Parameter(name = "CastkaTransakce")
    MWFBV5 castkaTransakce(Double castkaTransakce);
    @Parameter(name = "CisloCostCentra")
    MWFBV5 cisloCostCentra(String cisloCostCentra);
    @Parameter(name = "CisloUctuPlatce")
    MWFBV5 cisloUctuPlatce(String cisloUctuPlatce);
    @Parameter(name = "CisloUctuPrijemce")
    MWFBV5 cisloUctuPrijemce(String cisloUctuPrijemce);
    @Parameter(name = "CisloUctuPrijemceKodBanky")
    MWFBV5 cisloUctuPrijemceKodBanky(String cisloUctuPrijemceKodBanky);
    @Parameter(name = "DatumDalsiPlatby")
    MWFBV5 datumDalsiPlatby(java.util.Date datumDalsiPlatby);
    @Parameter(name = "DatumKonecnePlatby")
    MWFBV5 datumKonecnePlatby(java.util.Date datumKonecnePlatby);
    @Parameter(name = "DatumNarozeni")
    MWFBV5 datumNarozeni(java.util.Date datumNarozeni);
    @Parameter(name = "DatumOtevreni")
    MWFBV5 datumOtevreni(java.util.Date datumOtevreni);
    @Parameter(name = "DatumPrvniPlatby")
    MWFBV5 datumPrvniPlatby(java.util.Date datumPrvniPlatby);
    @Parameter(name = "DatumPrvnihoVypisu")
    MWFBV5 datumPrvnihoVypisu(java.util.Date datumPrvnihoVypisu);
    @Parameter(name = "DatumSplatnosti")
    MWFBV5 datumSplatnosti(java.util.Date datumSplatnosti);
    @Parameter(name = "DistribuceVypisu")
    MWFBV5 distribuceVypisu(String distribuceVypisu);
    @Parameter(name = "DruhKlienta")
    MWFBV5 druhKlienta(String druhKlienta);
    @Parameter(name = "DruheJmeno")
    MWFBV5 druheJmeno(String druheJmeno);
    @Parameter(name = "Jmeno")
    MWFBV5 jmeno(String jmeno);
    @Parameter(name = "KodBankyPrijemce")
    MWFBV5 kodBankyPrijemce(String kodBankyPrijemce);
    @Parameter(name = "KodMenyTransakce")
    MWFBV5 kodMenyTransakce(Long kodMenyTransakce);
    @Parameter(name = "KonstantniSymbol")
    MWFBV5 konstantniSymbol(String konstantniSymbol);
    @Parameter(name = "NazevUctuPlatce")
    MWFBV5 nazevUctuPlatce(String nazevUctuPlatce);
    @Parameter(name = "NazevUctuPrijemce")
    MWFBV5 nazevUctuPrijemce(String nazevUctuPrijemce);
    @Parameter(name = "ObchodniJmeno")
    MWFBV5 obchodniJmeno(String obchodniJmeno);
    @Parameter(name = "ObchodniMistoKod")
    MWFBV5 obchodniMistoKod(String obchodniMistoKod);
    @Parameter(name = "ObchodniMistoKodPlatce")
    MWFBV5 obchodniMistoKodPlatce(String obchodniMistoKodPlatce);
    @Parameter(name = "PausalniPoplatekPocetMesicuZdarma")
    MWFBV5 pausalniPoplatekPocetMesicuZdarma(Long pausalniPoplatekPocetMesicuZdarma);
    @Parameter(name = "Perioda")
    MWFBV5 perioda(String perioda);
    @Parameter(name = "PeriodaVypisu")
    MWFBV5 periodaVypisu(String periodaVypisu);
    @Parameter(name = "PoplatkovyPlan")
    MWFBV5 poplatkovyPlan(String poplatkovyPlan);
    @Parameter(name = "PostovniPoukazka")
    MWFBV5 postovniPoukazka(String postovniPoukazka);
    @Parameter(name = "PouzitaAA")
    MWFBV5 pouzitaAA(String pouzitaAA);
    @Parameter(name = "Prijmeni")
    MWFBV5 prijmeni(String prijmeni);
    @Parameter(name = "PrimarniUrednik")
    MWFBV5 primarniUrednik(String primarniUrednik);
    @Parameter(name = "ProduktKod")
    MWFBV5 produktKod(String produktKod);
    @Parameter(name = "Reference")
    MWFBV5 reference(String reference);
    @Parameter(name = "SFCisloTP")
    MWFBV5 sFCisloTP(String sFCisloTP);
    @Parameter(name = "SFMaterBU")
    MWFBV5 sFMaterBU(String sFMaterBU);
    @Parameter(name = "SFNazevUctu")
    MWFBV5 sFNazevUctu(String sFNazevUctu);
    @Parameter(name = "SFRozhodneObdobi")
    MWFBV5 sFRozhodneObdobi(String sFRozhodneObdobi);
    @Parameter(name = "SFVIPKlient")
    MWFBV5 sFVIPKlient(String sFVIPKlient);
    @Parameter(name = "SekundarniUrednik")
    MWFBV5 sekundarniUrednik(String sekundarniUrednik);
    @Parameter(name = "SpecifickyDen")
    MWFBV5 specifickyDen(Long specifickyDen);
    @Parameter(name = "SpecifickySymbol")
    MWFBV5 specifickySymbol(Long specifickySymbol);
    @Parameter(name = "TPVerifikova")
    MWFBV5 tPVerifikova(String tPVerifikova);
    @Parameter(name = "TitulPred")
    MWFBV5 titulPred(String titulPred);
    @Parameter(name = "TitulZa")
    MWFBV5 titulZa(String titulZa);
    @Parameter(name = "TypCRUctu")
    MWFBV5 typCRUctu(String typCRUctu);
    @Parameter(name = "TypSO")
    MWFBV5 typSO(String typSO);
    @Parameter(name = "UlozPSCBezKontroly")
    MWFBV5 ulozPSCBezKontroly(String ulozPSCBezKontroly);
    @Parameter(name = "Uzivatel")
    MWFBV5 uzivatel(String uzivatel);
    @Parameter(name = "VariabilniSymbol")
    MWFBV5 variabilniSymbol(Long variabilniSymbol);
    @Parameter(name = "VypisNaKonciMesice")
    MWFBV5 vypisNaKonciMesice(Boolean vypisNaKonciMesice);
    @Parameter(name = "ZpusobPripisu")
    MWFBV5 zpusobPripisu(String zpusobPripisu);
}
